@@ -1,7 +1,7 @@
 sub Mojo::Weixin::_login {
     my $self = shift;
     $self->info("客户端准备登录...");
-    my $api = 'https://login.weixin.qq.com/cgi-bin/mmwebwx-bin/login';
+    my $api = 'https://login.'. $self->domain .'/cgi-bin/mmwebwx-bin/login';
     if(not $self->_is_need_login()){
         $self->info("检测到近期登录活动，尝试直接恢复登录");
         $self->wxuin($self->search_cookie("wxuin"));
@@ -30,7 +30,7 @@ sub Mojo::Weixin::_login {
             loginicon => 'true',
             uuid    =>  $qrcode_uuid,
             tip     =>  $show_tip ,
-            r       =>  sub{use integer;~time}->(),
+            r       =>  sub{use integer;-1 * ~time}->(),
             _       =>  $self->now(),
         );
         my $r = $self->http_get($self->gen_url($api,@query_string));
@@ -40,6 +40,7 @@ sub Mojo::Weixin::_login {
         if($data{code} == 408){
             select undef,undef,undef,0.5;
             if($i==5){
+                $self->emit("qrcode_expire");
                 $self->info("登录二维码已失效，重新获取二维码");
                 $qrcode_uuid = $self->_get_qrcode_uuid();
                 $self->_get_qrcode_image($qrcode_uuid);
