@@ -210,43 +210,14 @@ sub call{
             $c->render(json=>{code=>100,status=>"object not found"});
         }
     };
-    any [qw(GET POST)] => '/openwx/send_message'         => sub{
-        my $c = shift;
-        my($id,$account,$displayname,$markname,$type,$content)= map {defined $_?Encode::encode("utf8",$_):$_} ($c->param("id"),$c->param("account"),$c->param("displayname"),$c->param("markname"),$c->param("type"),$c->param("content"));
-        my $object;
-        if(defined $type){
-            if($type eq "group_message"){
-                $object = $client->search_group(id=>$id,displayname=>$displayname); 
-            }
-            else{
-                $object = $client->search_friend(id=>$id,account=>$account,displayname=>$displayname,markname=>$markname);
-            }
-        }
-        elsif(defined $id){
-            $object = $client->is_group($id)?$client->search_group(id=>$id,displayname=>$displayname):$client->search_friend(id=>$id,account=>$account,displayname=>$displayname,markname=>$markname);
-        }
-        else{
-            $object = $client->search_friend(id=>$id,account=>$account,displayname=>$displayname,markname=>$markname);
-        }
-        if(defined $object){
-            $c->render_later;
-            $client->send_message($object,$content,sub{
-                my $msg= $_[1];
-                $msg->cb(sub{
-                    my($client,$msg,$status)=@_;
-                    $c->render(json=>{msg_id=>$msg->id,code=>$status->code,status=>Encode::decode("utf8",$status->msg)});  
-                });
-                $msg->from("api");
-            });
-        }
-        else{$c->render(json=>{msg_id=>undef,code=>100,status=>"object not found"});}
-    };
     any [qw(GET POST)] => '/openwx/send_friend_message'         => sub{
         my $c = shift;
         my($id,$account,$displayname,$markname,$content)= map {defined $_?Encode::encode("utf8",$_):$_} ($c->param("id"),$c->param("account"),$c->param("displayname"),$c->param("markname"),$c->param("content"));
-        my($media_mime,$media_name,$media_size,$media_data,$media_mtime,$media_ext,$media_path) = 
+        my($media_id,$media_type,$media_mime,$media_name,$media_size,$media_data,$media_mtime,$media_ext,$media_path) = 
             map {defined $_?Encode::encode("utf8",$_):$_} 
         (
+            $c->param("media_id"),
+            $c->param("media_type"),
             $c->param("media_mime"),
             $c->param("media_name"),
             $c->param("media_size"),
@@ -256,10 +227,12 @@ sub call{
             $c->param("media_path"),
         );
         if(defined $id and $id eq '@all'){#群发给所有好友
-            for my $f (grep {$_->displayname =~/小冰|autolife|machine/} $client->friends){
+            for my $f ($client->friends){
                 $client->send_message($f,$content,sub{my $msg= $_[1];$msg->from("api");}) if defined $content;
                 if(defined $media_data or defined $media_path){
                     $client->send_media($f,{
+                            media_id    =>  $media_id,
+                            media_type  =>  $media_type,
                             media_mime  =>  $media_mime,
                             media_name  =>  $media_name,
                             media_size  =>  $media_size,
@@ -285,8 +258,10 @@ sub call{
                 });
                 $msg->from("api");
             }) if defined $content;
-            if(defined $media_data or defined $media_path){
+            if(defined $media_data or defined $media_path or defined $media_id){
                 $client->send_media($object,{
+                    media_id    =>  $media_id,
+                    media_type  =>  $media_type,
                     media_mime  =>  $media_mime,
                     media_name  =>  $media_name,
                     media_size  =>  $media_size,
@@ -298,7 +273,7 @@ sub call{
                     my $msg= $_[1];
                     $msg->cb(sub{
                         my($client,$msg,$status)=@_;
-                        $c->render(json=>{msg_id=>$msg->id,code=>$status->code,status=>Encode::decode("utf8",$status->msg)});
+                        $c->render(json=>{msg_id=>$msg->id,media_id=>join(":",$msg->media_id,$msg->media_code),code=>$status->code,status=>Encode::decode("utf8",$status->msg)});
                     });
                     $msg->from("api");
                 });
@@ -309,9 +284,11 @@ sub call{
     any [qw(GET POST)] => '/openwx/send_group_message'         => sub{
         my $c = shift;
         my($id,$account,$displayname,$markname,$content)= map {defined $_?Encode::encode("utf8",$_):$_} ($c->param("id"),$c->param("account"),$c->param("displayname"),$c->param("markname"),$c->param("content"));
-        my($media_mime,$media_name,$media_size,$media_data,$media_mtime,$media_ext,$media_path) =
+        my($media_id,$media_type,$media_mime,$media_name,$media_size,$media_data,$media_mtime,$media_ext,$media_path) =
             map {defined $_?Encode::encode("utf8",$_):$_}
         (
+            $c->param("media_id"),
+            $c->param("media_type"),
             $c->param("media_mime"),
             $c->param("media_name"),
             $c->param("media_size"),
@@ -331,8 +308,10 @@ sub call{
                 });
                 $msg->from("api");
             }) if defined $content;
-            if(defined $media_data or defined $media_path){
+            if(defined $media_data or defined $media_path or defined $media_id){
                 $client->send_media($object,{
+                    media_id    =>  $media_id,
+                    media_type  =>  $media_type,
                     media_mime  =>  $media_mime,
                     media_name  =>  $media_name,
                     media_size  =>  $media_size,
@@ -344,7 +323,7 @@ sub call{
                     my $msg= $_[1];
                     $msg->cb(sub{
                         my($client,$msg,$status)=@_;
-                        $c->render(json=>{msg_id=>$msg->id,code=>$status->code,status=>Encode::decode("utf8",$status->msg)});
+                        $c->render(json=>{msg_id=>$msg->id,media_id=>join(":",$msg->media_id,$msg->media_code),code=>$status->code,status=>Encode::decode("utf8",$status->msg)});
                     });
                     $msg->from("api");
                 });
@@ -355,9 +334,11 @@ sub call{
     any [qw(GET POST)] => '/openwx/consult'         => sub{
         my $c = shift;
         my($id,$account,$displayname,$markname,$content,$timeout)= map {defined $_?Encode::encode("utf8",$_):$_} ($c->param("id"),$c->param("account"),$c->param("displayname"),$c->param("markname"),$c->param("content"),$c->param("timeout"));
-        my($media_mime,$media_name,$media_size,$media_data,$media_mtime,$media_ext,$media_path) =
+        my($media_id,$media_type,$media_mime,$media_name,$media_size,$media_data,$media_mtime,$media_ext,$media_path) =
             map {defined $_?Encode::encode("utf8",$_):$_}
         (
+            $c->param("media_id"),
+            $c->param("media_type"),
             $c->param("media_mime"),
             $c->param("media_name"),
             $c->param("media_size"),
@@ -386,8 +367,10 @@ sub call{
                 });
                 $msg->from("api");
             }) if defined $content;
-            if(defined $media_data or defined $media_path){
+            if(defined $media_data or defined $media_path or defined $media_id){
                 $client->send_media($object,{
+                    media_id    =>  $media_id,
+                    media_type  =>  $media_type,
                     media_mime  =>  $media_mime,
                     media_name  =>  $media_name,
                     media_size  =>  $media_size,
@@ -399,7 +382,7 @@ sub call{
                     my $msg= $_[1];
                     $msg->cb(sub{
                         my($client,$msg,$status)=@_;
-                        $c->render(json=>{msg_id=>$msg->id,code=>$status->code,status=>Encode::decode("utf8",$status->msg)});
+                        $c->render(json=>{msg_id=>$msg->id,media_id=>join(":",$msg->media_id,$msg->media_code),code=>$status->code,status=>Encode::decode("utf8",$status->msg)});
                     });
                     $msg->from("api");
                 });
@@ -566,6 +549,64 @@ sub call{
         }
         else{$c->render(json=>{msg_id=>undef,code=>100,status=>"object not found"});}
 
+    };
+    any [qw(GET POST)] => '/openwx/get_client_info' => sub{
+        my $c = shift;
+        $c->render(json=>{
+            code=>0,
+            pid=>$$,
+            account=>$client->account,
+            os=>$^O,
+            version=>$client->version,
+            starttime=>$client->start_time,
+            runtime=>int(time - $client->start_time),
+            http_debug=>$client->http_debug,
+            log_encoding=>$client->log_encoding,
+            log_path=>Mojo::Util::decode("utf8",$client->log_path||""),
+            log_level=>$client->log_level,
+            status=>"success",
+        });
+    };
+    any [qw(GET POST)] => '/openwx/stop_client' => sub{
+        my $c = shift;
+        $c->render(json=>{
+            code=>0,
+            account=>$client->account,
+            pid=>$$,
+            starttime=>$client->start_time,
+            runtime=>int(time - $client->start_time),
+            status=>"success, client($$) will stop in 3 seconds",
+        });
+        $client->timer(3=>sub{$client->stop()});#3秒后再执行，让客户端可以收到该api的响应
+    };
+    any [qw(GET POST)] => '/openwx/upload_media' => sub{
+        my $c = shift;
+        my($media_type,$media_mime,$media_name,$media_size,$media_data,$media_mtime,$media_ext,$media_path) =
+            map {defined $_?Encode::encode("utf8",$_):$_}
+        (
+            $c->param("media_type"),
+            $c->param("media_mime"),
+            $c->param("media_name"),
+            $c->param("media_size"),
+            $c->param("media_data"),
+            $c->param("media_mtime"),
+            $c->param("media_ext"),
+            $c->param("media_path"),
+        );
+        $c->render_later;
+        $client->upload_media({
+                media_type  => $media_type,
+                media_mime  => $media_mime,
+                media_name  => $media_name,
+                media_size  => $media_size,
+                media_data  => $media_data,
+                media_mtime => $media_mtime,
+                media_ext   => $media_ext,
+                media_path  => $media_path,
+            },
+            sub{my $json = shift;$client->reform_hash($json,1);$c->render(json=>$json) if defined $c}
+        );
+        
     };
     any '/*whatever'  => sub{whatever=>'',$_[0]->render(text=>"api not found",status=>403)};
     package Mojo::Weixin::Plugin::Openwx;
